pub(crate) struct ThreadInit {
pub handle: Thread,
pub rust_start: Box<dyn FnOnce() + Send>,
}Expand description
The data passed to the spawned thread for thread initialization. Any thread implementation should start a new thread by calling .init() on this before doing anything else to ensure the current thread is properly initialized and the global allocator works.
Fields
handle: Threadrust_start: Box<dyn FnOnce() + Send>Implementations